# image_operations

Description. 
The package image_operations is used to:
	- Flip an image. All tranpose modes.
	- Get channels from an image and print them with its image.

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install image_operations

```bash
pip install image_operations
```

## Author
Celso

## License
[MIT](https://choosealicense.com/licenses/mit/)
